@@ -19,27 +19,27 @@
         <translation>Клиент</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="147"/>
+        <location filename="../default_model.cpp" line="141"/>
         <source>Id</source>
-        <translation>id</translation>
+        <translation>Id</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="150"/>
+        <location filename="../default_model.cpp" line="144"/>
         <source>Shortcut</source>
         <translation>Сочетание клавиш</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="153"/>
+        <location filename="../default_model.cpp" line="147"/>
         <source>Description</source>
         <translation>Описание</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="156"/>
+        <location filename="../default_model.cpp" line="150"/>
         <source>Type</source>
         <translation>Тип</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="159"/>
+        <location filename="../default_model.cpp" line="153"/>
         <source>Info</source>
         <translation>Информация</translation>
     </message>
@@ -117,7 +117,7 @@
     <message>
         <location filename="../main_window.ui" line="52"/>
         <source>Add ...</source>
-        <translation>Добавить…</translation>
+        <translation>Добавить...</translation>
     </message>
     <message>
         <location filename="../main_window.ui" line="62"/>
@@ -127,7 +127,7 @@
     <message>
         <location filename="../main_window.ui" line="72"/>
         <source>Modify ...</source>
-        <translation>Изменить…</translation>
+        <translation>Изменить...</translation>
     </message>
     <message>
         <location filename="../main_window.ui" line="89"/>
@@ -137,7 +137,7 @@
     <message>
         <location filename="../main_window.ui" line="115"/>
         <source>Multiple actions behaviour:</source>
-        <translation>Поведение нескольких действий:</translation>
+        <translation>При наличии нескольких действий выполнять:</translation>
     </message>
     <message>
         <location filename="../main_window.ui" line="123"/>
@@ -152,7 +152,7 @@
     <message>
         <location filename="../main_window.ui" line="133"/>
         <source>None</source>
-        <translation>Не задано</translation>
+        <translation type="unfinished">Нет</translation>
     </message>
     <message>
         <location filename="../main_window.ui" line="138"/>
